Makes sure the user inputted random forest is able to be loaded
Usage
checkRF_path(rf_path, anc_list)
Arguments
- rf_path
[character] /path/to/directory where the rds file for a user inputted
classification model is located Note that the name of the file including the .rds or
.RDS extenstion must be included
- anc_list
[list] List of the names used for labels for the random forest
Examples
rf_path <- '/path/to/model/model.rds'
if (FALSE) { # \dontrun{
# the following code is not run on package build, as the path2load_mat on the
# user system is not known.
checkRF_path(rf_path = rf_path)
} # }