| checkRF_path | R Documentation |
Makes sure the user inputted random forest is able to be loaded
checkRF_path(rf_path, anc_list)
rf_path |
[character] /path/to/directory where the rds file for a user inputted classification model is located Note that the name of the file including the .rds or .RDS extenstion must be included |
anc_list |
[list] List of the names used for labels for the random forest |
rf_path <- '/path/to/model/model.rds'
## Not run:
# the following code is not run on package build, as the path2load_mat on the
# user system is not known.
checkRF_path(rf_path = rf_path)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.